@@ -5,6 +5,14 @@
 (*    You may freely copy parts of it in your application.                *)
 (*                                                                        *)
 (**************************************************************************)
+(* #require "lablgtksourceview2.gtksourceview2";; *)
+
+let provider =
+  let open GSourceView2 in
+  let provider_ref = ref None in
+  let provided_list = ["toto"; "titi"; "tata"] in
+  let do_provider () = match !provider_ref with None -> assert false | Some x -> x in
+  let populate context =
     let ctx = new source_completion_context context in
     let item s = source_completion_item ~label:s ~text:s () in
     let proposal s = (item s :> source_completion_proposal) in
@@ -12,7 +20,7 @@
     ctx#add_proposals (do_provider ()) proposals true
   in
   let info_widget provider =
-    let label = GMisc.label ~text:"toto" () in 
+    let label = GMisc.label ~text:"toto" () in
     Some (label#coerce#as_widget)
   in
   let provider =
