@@ -20,7 +20,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: gMisc.mli 1527 2010-09-09 08:02:22Z garrigue $ *)
+(* $Id$ *)
 
 open Gtk
 open GObj
@@ -77,6 +77,9 @@ class status_icon_signals : Gtk.status_icon Gobject.obj ->
     method activate : callback:(unit -> unit) -> GtkSignal.id
     method popup_menu : callback:(int -> int -> unit) -> GtkSignal.id
     method size_changed : callback:(int -> unit) -> GtkSignal.id
+    method notify_blinking : callback:(bool -> unit) -> GtkSignal.id
+    method notify_screen : callback:(Gdk.screen -> unit) -> GtkSignal.id
+    method notify_visible : callback:(bool -> unit) -> GtkSignal.id
   end
 
 (** Display an icon in the system tray.
@@ -131,6 +134,9 @@ class calendar_signals : 'a obj ->
     method next_year : callback:(unit -> unit) -> GtkSignal.id
     method prev_month : callback:(unit -> unit) -> GtkSignal.id
     method prev_year : callback:(unit -> unit) -> GtkSignal.id
+    method notify_day : callback:(int -> unit) -> GtkSignal.id
+    method notify_month : callback:(int -> unit) -> GtkSignal.id
+    method notify_year : callback:(int -> unit) -> GtkSignal.id
   end
 
 (** Display a calendar and/or allow the user to select a date
@@ -261,7 +267,8 @@ val arrow :
   ?packing:(widget -> unit) -> ?show:bool -> unit -> arrow
 
 type image_type =
-  [ `EMPTY | `PIXMAP | `IMAGE | `PIXBUF | `STOCK | `ICON_SET | `ANIMATION ]
+  [ `EMPTY | `PIXMAP | `IMAGE | `PIXBUF | `STOCK | `ICON_SET | `ANIMATION
+  | `ICON_NAME | `GICON ]
 
 (** A widget displaying an image
     @gtkdoc gtk GtkImage *)
@@ -414,6 +421,10 @@ class tips_query_signals : Gtk.tips_query obj ->
       callback:(widget option -> text:string -> privat:string ->
                 GdkEvent.Button.t -> bool) ->
       GtkSignal.id
+    method notify_caller : callback:(GObj.widget option -> unit) -> GtkSignal.id
+    method notify_emit_always : callback:(bool -> unit) -> GtkSignal.id
+    method notify_label_inactive : callback:(string -> unit) -> GtkSignal.id
+    method notify_label_no_tip : callback:(string -> unit) -> GtkSignal.id
   end
 
 (** Displays help about widgets in the user interface
