@@ -20,7 +20,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: gtkTree.ml 1455 2009-05-12 10:31:37Z garrigue $ *)
+(* $Id$ *)
 
 open Gaux
 open Gtk
@@ -58,7 +58,10 @@ module TreePath = struct
   let () =
     Internal.tree_path_string :=
       {kind=`STRING; inj=(fun x -> string.inj (to_string x));
-       proj=(fun x -> from_string (string.proj x))}
+       proj=(fun x -> from_string (string.proj x))};
+    Internal.tree_path_copy :=
+      {kind=`POINTER; inj=unsafe_pointer.inj;
+       proj=(fun x -> copy (unsafe_pointer.proj x))}
 end
 
 module RowReference = struct
@@ -71,7 +74,7 @@ module RowReference = struct
 end
 
 module TreeModel = struct
-  let cast w : tree_model obj = Object.try_cast w "GtkTreeModel"
+  let cast w : tree_model = Object.try_cast w "GtkTreeModel"
   external get_flags : [>`treemodel] obj -> GtkEnums.tree_model_flags list
     = "ml_gtk_tree_model_get_flags"
   external get_n_columns : [>`treemodel] obj -> int
