@@ -20,7 +20,7 @@
 /*                                                                        */
 /**************************************************************************/
 
-/* $Id: ml_gtktree.c 1496 2010-01-14 15:38:03Z ben_99_9 $ */
+/* $Id$ */
 
 #include <string.h>
 #include <gtk/gtk.h>
@@ -525,7 +525,7 @@ ml_gtk_tree_view_enable_model_drag_dest (value tv, value t, value a)
       , Abstract_tag );
   for (i=0; i<n_targets; i++)
   {
-    targets[i].target = String_val(Field(Field(t, i), 0));
+    targets[i].target = Bytes_val(Field(Field(t, i), 0));
     targets[i].flags  = Flags_Target_flags_val(Field(Field(t, i), 1));
     targets[i].info   = Int_val(Field(Field(t, i), 2));
   }
@@ -551,7 +551,7 @@ ml_gtk_tree_view_enable_model_drag_source (value tv, value m, value t, value a)
       , Abstract_tag );
   for (i=0; i<n_targets; i++)
   {
-    targets[i].target = String_val(Field(Field(t, i), 0));
+    targets[i].target = Bytes_val(Field(Field(t, i), 0));
     targets[i].flags  = Flags_Target_flags_val(Field(Field(t, i), 1));
     targets[i].info   = Int_val(Field(Field(t, i), 2));
   }
@@ -884,9 +884,11 @@ Unsupported_24 (gtk_tree_model_filter_convert_iter_to_child_iter)
 /* GtkIconView */
 #ifdef HASGTK26
 #define GtkIconView_val(val) check_cast(GTK_ICON_VIEW,val)
-#define Val_option_GtkTreePath(v) Val_option(v,Val_GtkTreePath)
-ML_3 (gtk_icon_view_get_path_at_pos, GtkIconView_val, Int_val, Int_val, Val_option_GtkTreePath)
-static void ml_iconview_foreach (GtkIconView *icon_view, GtkTreePath *path, gpointer data)
+static Make_Val_option(GtkTreePath)
+ML_3 (gtk_icon_view_get_path_at_pos, GtkIconView_val, Int_val, Int_val,
+      Val_option_GtkTreePath)
+static void ml_iconview_foreach (GtkIconView *icon_view, GtkTreePath *path,
+				 gpointer data)
 {
   value *cb = data;
   value p;
@@ -1149,9 +1151,7 @@ encode_iter(Custom_model *custom_model, GtkTreeIter *iter, value v)
   /* Ideally, the user would already have ensured all these were stable...
      and in any case, it is always up to the user to ensure that they will
      not get garbage collected */
-    if((Is_block(v1) && (char*)v1 < (char*)caml_young_end && (char*)v1 > (char*)caml_young_start) ||
-       (Is_block(v2) && (char*)v2 < (char*)caml_young_end && (char*)v2 > (char*)caml_young_start) ||
-       (Is_block(v3) && (char*)v3 < (char*)caml_young_end && (char*)v3 > (char*)caml_young_start))
+    if(Is_young_block(v1) || Is_young_block(v2) || Is_young_block(v3))
       {
 	caml_register_global_root (&v1);
 	caml_register_global_root (&v2);
@@ -1487,8 +1487,8 @@ CAMLprim value ml_register_custom_model_callback_object(value custom_model,
   GObject *obj = GObject_val(custom_model);
   g_return_val_if_fail (IS_CUSTOM_MODEL (obj),Val_unit);
   if(Is_block(callback_object) &&
-      (char*)callback_object < (char*)caml_young_end &&
-      (char*)callback_object > (char*)caml_young_start)
+      (char*)callback_object < (char*)young_end &&
+      (char*)callback_object > (char*)young_start)
     {
       caml_register_global_root (&callback_object);
       caml_minor_collection();
@@ -1580,6 +1580,7 @@ CAMLprim value ml_custom_model_rows_reordered (value tree_model_val, value path,
   return Val_unit;)
 }
 
+#ifdef HASGTK28
 CAMLprim value ml_gtk_tree_view_get_visible_range(value treeview) {
      CAMLparam1(treeview);
      CAMLlocal1(result);
@@ -1592,4 +1593,7 @@ CAMLprim value ml_gtk_tree_view_get_visible_range(value treeview) {
      Store_field(result, 1, Val_GtkTreePath(endp));
      CAMLreturn(ml_some(result));
 }
-	  
+#else
+Unsupported_28(gtk_tree_view_get_visible_range)
+#endif
+
